@@ -188,14 +188,14 @@ class BodyParser:
 
         return body
 
-    def _parse_attachments_rec(self, msg, save_path, msg_id, max_attachment_size, random_filenames):
+    def _parse_attachments_rec(self, msg, msg_id):
         attachments_jsons = []
         for payload in msg.get_payload():
             if type(payload) != str:
                 if (payload.get_content_disposition() == "attachment"
                     and payload.get_content_type() != "message/rfc822"):
 
-                    a_parser = AttachmentParser(payload, save_path, msg_id, max_attachment_size, random_filenames)
+                    a_parser = AttachmentParser(payload, msg_id)
                     attachment_data = a_parser.parse()
 
                     if a_parser.fails != {}:
@@ -203,12 +203,12 @@ class BodyParser:
 
                     attachments_jsons.append(attachment_data)
                 elif payload.is_multipart() and payload.get_content_type() != "message/rfc822":
-                    attachments_jsons += self._parse_attachments_rec(payload, save_path, msg_id, max_attachment_size, random_filenames)
+                    attachments_jsons += self._parse_attachments_rec(payload, msg_id)
 
         return attachments_jsons
 
-    def parse_attachments(self, save_path, msg_id, max_attachment_size, random_filenames):
-        return self._parse_attachments_rec(self.msg, save_path, msg_id, max_attachment_size, random_filenames)
+    def parse_attachments(self, msg_id):
+        return self._parse_attachments_rec(self.msg, msg_id)
 
     def _clean_html(self, payload):
         soup = BeautifulSoup(payload, features="lxml")
@@ -221,46 +221,20 @@ class BodyParser:
 
 
 class AttachmentParser(BodyParser):
-    def __init__(self, msg, save_path, msg_id, max_attachment_size, random_filenames):
+    def __init__(self, msg, msg_id):
         BodyParser.__init__(self, msg)
-        self.save_path = save_path
         self.msg_id = msg_id
-        self.max_attachment_size = max_attachment_size
-        self.random_filenames = random_filenames
 
     def parse(self):
         attachment_id = str(getrandbits(64))
-        attachment_json = {"msg_id": self.msg_id, "attachment_id": attachment_id}
+        attachment_json = {"parent_id": self.msg_id, "id": attachment_id}
 
         filename = self._get_filename()
         ext = os.path.splitext(filename)[-1]
         attachment_json["filename"] = filename
 
         if(ext not in DIGIDOC_FORMATS):
-            attachment_json["content"] = self._parse_attachment()
-
-        if self.save_path != None and filename != "":
-            attachment_dir = os.path.join(self.save_path, self.msg_id)
-
-            if(self.random_filenames):
-                ext = os.path.splitext(filename)[-1]
-                random_filename = uuid.uuid4().hex + ext
-                attachment_path = os.path.join(attachment_dir, random_filename)
-            else:
-                attachment_path = os.path.join(attachment_dir, filename)
-            self._make_dir(attachment_dir)
-
-            try:
-                with open(attachment_path, "wb") as f:
-                    f.write(self.msg.get_payload(decode=True))
-                attachment_json["filepath"] = attachment_path  
-            except OSError:
-                exc_type, value, _ = sys.exc_info()
-                self.fails["filename"] = "{}: {}".format(exc_type.__name__, value)
-            except TypeError:
-                exc_type, value, _ = sys.exc_info()
-                self.fails["filepath"] = "{}: {}".format(exc_type.__name__, value)
-                
+            attachment_json["content"] = self._get_payload()
 
         return attachment_json
 
@@ -291,32 +265,12 @@ class AttachmentParser(BodyParser):
 
         return "".join(filename_items)
 
-    def _parse_attachment(self):
+    def _get_payload(self):
+        """
+        Simply returns decoded payload (binary).
+        """
         attachment_payload = self.msg.get_payload(decode=True)
-        if(attachment_payload == None):
-            self.fails["content"] = "{}".format("No payload")
-            return ""
-        
-        if(not self._file_size_ok(attachment_payload)):
-            self.fails["content"] = "File too large for content parsing."
-            return ""
-        else:
-            result = tika_parser.from_buffer(attachment_payload)
-            content = result["content"]
-
-            if result["status"] != 200:
-                self.fails["content"] = "{}: {}".format("tika", result["status"])
-            if content == None:
-                return ""
-
-            lines = (line.strip() for line in content.splitlines())
-            text = "\n".join(line for line in lines if line)
-            return text
-
-    def _file_size_ok(self, payload):
-        if(len(payload) > self.max_attachment_size*1024**2):
-            return False
-        return True
+        return attachment_payload
 
     def _make_dir(self, f_dir):
         if not os.path.exists(f_dir):
