@@ -1,4 +1,5 @@
 from enum import Enum
+import subprocess
 from ..settings import META_FIELD
 from texta_parsers.tools.extension import Extension
 
@@ -21,3 +22,11 @@ def get_output_type(item):
             return ParserOutputType.COLLECTION
         else:
             return ParserOutputType.FILE
+
+
+def check_digidoc_exists():
+    try:
+        p = subprocess.run(["digidoc-tool"], stdout=subprocess.PIPE)
+        return True
+    except FileNotFoundError:
+        return False
